@@ -30,6 +30,8 @@
 #    17-May-2010 (MPH) Fixed 'iter_*' on empty items
 #     3-Aug-2010 (MPR) Fixed '__repr__' of 'Connection'
 #     2-Nov-2010 (MPR) Added 'finish' to 'Connection'
+#    31-Jul-2013 (MPR) Added caching to 1wire communication, to improve
+#                      searching on large trees
 #    revision-date
 #--
 import libcapi
@@ -80,7 +82,7 @@ class Dir (object) :
                         yield e
     # end def iter_entries
 
-    def get (self, key) :
+    def get (self, key, cached = True) :
         """Get a given entry.
 
         Basically this resembles a read access to self.path/key.
@@ -93,7 +95,8 @@ class Dir (object) :
             else :
                 basename = e.split ("/") [-1]
                 if key == basename :
-                    return self.capi.get ("%s%s" % (self.path, e))
+                    return self.capi.get \
+                        ("%s%s" % (self.path, e), cached = cached)
         raise KeyError (key)
     # end def get
 
